@@ -121,6 +121,7 @@ class CortxJupyter(ContentsManager):
     aws_s3_host = Unicode(config=True)
     aws_region = Unicode(config=True)
     prefix = Unicode(config=True)
+    endpoint_url = Unicode(config=True)
 
     authentication_class = Type(CortxJupyterAuthentication, config=True)
     authentication = Instance(CortxJupyterAuthentication)
@@ -796,7 +797,9 @@ SAVERS = {
 s3_client = boto3.client('s3',
             aws_access_key_id = AwsCreds.access_key_id,
             aws_secret_access_key = AwsCreds.secret_access_key,
-            region_name = 'us-east-1')
+            region_name = 'us-east-1',
+            endpoint_url = Context.endpoint_url
+            )
 
 
 def _head_object(bucket, key):
